# Fetch ERC20 Contract

## Description

This contract package is used to interface with a Fetch ERC20 contract.

## Functions

* approve(spender, amount): approve address `spender` to transfer up to `amount` tokens on behalf of sender
* transfer(receiver, amount): transfer `amount` tokens from sender to receiver